@@ -23,6 +23,7 @@ function(lo=NULL, hi=NULL, mu=0, sigma=1, col.nrm="black",
 
   
   # normal density curve
+  .graphwin()
   min.x <- mu-4*sigma
   max.x <- mu+4*sigma
   cuts <- seq(min.x,max.x,sigma)
@@ -56,4 +57,6 @@ function(lo=NULL, hi=NULL, mu=0, sigma=1, col.nrm="black",
   lbl3 <- bquote(paste(mu, "=", .(mu), "  ", sigma, "=", .(sigma)))
   if (z) title(sub=lbl3, line=4, ...) else title(sub=lbl3, ...)
 
+  return(prob)
+
 }
